niftianon
=========

Anonymiser for NIFTI format images.


Installation
------------

.. code::

    git clone https://github.com/jstutters/niftianon
    cd niftianon
    pip install .


Usage
-----

.. code::

    niftianon [path to identifiable image] [path to anonymised image]

The anonymised image path must not exist.
